@@ -152,4 +152,7 @@ hierarchical$methods(
   }
 )
 
+DSC_registry$set_entry(name = "DSC_Hierarchical",
+  DSC_Micro = FALSE, DSC_Macro = TRUE,
+  description = "Hierarchical reclustering")
 
