@@ -108,6 +108,9 @@ Static$methods(
   }
 )
 
+DSC_registry$set_entry(name = "DSC_Static",
+  DSC_Micro = TRUE, DSC_Macro = TRUE,
+  description = "Static Copy of a Clustering")
 
 
 
