@@ -23,4 +23,7 @@ DSC_Window <- function(horizon = 100, lambda=0)
     class = c("DSC_Window","DSC_Micro","DSC_R","DSC"))
 
 
-
+DSC_registry$set_entry(name = "DSC_Window",
+  DSC_Micro = TRUE, DSC_Macro = FALSE,
+  description = "Sliding window")
+                                       
