@@ -386,7 +386,15 @@ plot(dstream, stream, grid = TRUE)
 
 
 ###################################################
-### code chunk number 52: stream.Rnw:2228-2232
+### code chunk number 52: stream.Rnw:1878-1881
+###################################################
+DSC_registry
+
+head(DSC_registry$get_entries(), n = 3)
+
+
+###################################################
+### code chunk number 53: stream.Rnw:2238-2242
 ###################################################
 library("stream")
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
@@ -395,19 +403,19 @@ update(dstream, stream, n = 2000)
 
 
 ###################################################
-### code chunk number 53: stream.Rnw:2240-2241
+### code chunk number 54: stream.Rnw:2250-2251
 ###################################################
 evaluate(dstream, stream, n = 100)
 
 
 ###################################################
-### code chunk number 54: stream.Rnw:2252-2253
+### code chunk number 55: stream.Rnw:2262-2263
 ###################################################
 evaluate(dstream, stream, measure = c("purity", "crand"), n = 500)
 
 
 ###################################################
-### code chunk number 55: stream.Rnw:2294-2300
+### code chunk number 56: stream.Rnw:2304-2310
 ###################################################
 set.seed(1000)
 stream <- DSD_Benchmark(1)
@@ -418,14 +426,14 @@ head(ev)
 
 
 ###################################################
-### code chunk number 56: evaluation
+### code chunk number 57: evaluation
 ###################################################
 plot(ev[ , "points"], ev[ , "purity"], type = "l",
   ylab = "Avg. Purity", xlab = "Points")
 
 
 ###################################################
-### code chunk number 57: stream.Rnw:2333-2338 (eval = FALSE)
+### code chunk number 58: stream.Rnw:2343-2348 (eval = FALSE)
 ###################################################
 ## set.seed(1000)
 ## stream <- DSD_Benchmark(1)
@@ -435,7 +443,7 @@ plot(ev[ , "points"], ev[ , "purity"], type = "l",
 
 
 ###################################################
-### code chunk number 58: stream.Rnw:2368-2375
+### code chunk number 59: stream.Rnw:2378-2385
 ###################################################
 library("stream")
 set.seed(1000)
@@ -447,13 +455,13 @@ dstream
 
 
 ###################################################
-### code chunk number 59: recluster
+### code chunk number 60: recluster
 ###################################################
 plot(dstream, stream, type = "both")
 
 
 ###################################################
-### code chunk number 60: recluster2
+### code chunk number 61: recluster2
 ###################################################
 km <- DSC_Kmeans(k = 3, weighted = TRUE)
 recluster(km, dstream)
@@ -462,20 +470,20 @@ plot(km, stream, type = "both")
 
 
 ###################################################
-### code chunk number 61: stream.Rnw:2436-2437
+### code chunk number 62: stream.Rnw:2446-2447
 ###################################################
 evaluate(km, stream, measure = c("purity", "crand", "SSQ"), n = 1000)
 
 
 ###################################################
-### code chunk number 62: stream.Rnw:2442-2444
+### code chunk number 63: stream.Rnw:2452-2454
 ###################################################
 evaluate(km, stream, c(measure = "purity", "crand", "SSQ"), n = 1000,
   assign = "macro")
 
 
 ###################################################
-### code chunk number 63: stream.Rnw:2467-2470
+### code chunk number 64: stream.Rnw:2477-2480
 ###################################################
 points <- get_points(stream, n = 100)
 assignment <- get_assignment(dstream, points, type = "macro")
@@ -483,7 +491,7 @@ assignment
 
 
 ###################################################
-### code chunk number 64: silhouette
+### code chunk number 65: silhouette
 ###################################################
 assignment[is.na(assignment)] <- 0L
 library("cluster")
@@ -491,7 +499,7 @@ plot(silhouette(assignment, dist = dist(points)))
 
 
 ###################################################
-### code chunk number 65: stream.Rnw:2505-2517
+### code chunk number 66: stream.Rnw:2515-2527
 ###################################################
 library("stream")
 CustomCallback <- function() {
@@ -508,7 +516,7 @@ CustomCallback <- function() {
 
 
 ###################################################
-### code chunk number 66: stream.Rnw:2524-2534
+### code chunk number 67: stream.Rnw:2534-2544
 ###################################################
 evaluate_callback.CustomCallback <- function(cb_obj, dsc, measure, points,
                                              actual, predict, outliers,
@@ -523,7 +531,7 @@ evaluate_callback.CustomCallback <- function(cb_obj, dsc, measure, points,
 
 
 ###################################################
-### code chunk number 67: stream.Rnw:2545-2551
+### code chunk number 68: stream.Rnw:2555-2561
 ###################################################
 stream <- DSD_Gaussians(k = 3, d = 2, p = c(0.2, 0.4, 0.4))
 km <- DSC_Kmeans(3)
@@ -534,7 +542,7 @@ evaluate_with_callbacks(km, stream, type="macro", n=500,
 
 
 ###################################################
-### code chunk number 68: data_bng
+### code chunk number 69: data_bng
 ###################################################
 set.seed(1000)
 library("stream")
@@ -544,7 +552,7 @@ plot(stream)
 
 
 ###################################################
-### code chunk number 69: stream.Rnw:2745-2753
+### code chunk number 70: stream.Rnw:2755-2763
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100),
@@ -557,7 +565,7 @@ algorithms <- list(
 
 
 ###################################################
-### code chunk number 70: stream.Rnw:2763-2767
+### code chunk number 71: stream.Rnw:2773-2777
 ###################################################
 for(a in algorithms) {
   reset_stream(stream)
@@ -566,13 +574,13 @@ for(a in algorithms) {
 
 
 ###################################################
-### code chunk number 71: stream.Rnw:2772-2773
+### code chunk number 72: stream.Rnw:2782-2783
 ###################################################
 sapply(algorithms, nclusters, type = "micro")
 
 
 ###################################################
-### code chunk number 72: microclusters
+### code chunk number 73: microclusters
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
@@ -584,7 +592,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 73: microclusters_assignment
+### code chunk number 74: microclusters_assignment
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
@@ -597,7 +605,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 74: stream.Rnw:2851-2858
+### code chunk number 75: stream.Rnw:2861-2868
 ###################################################
 sapply(algorithms, FUN=function(a) {
   reset_stream(stream, pos = 1001)
@@ -609,7 +617,7 @@ sapply(algorithms, FUN=function(a) {
 
 
 ###################################################
-### code chunk number 75: macroclusters
+### code chunk number 76: macroclusters
 ###################################################
 op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:length(algorithms), ncol = 2))
@@ -621,7 +629,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 76: stream.Rnw:2902-2908
+### code chunk number 77: stream.Rnw:2912-2918
 ###################################################
 sapply(algorithms, FUN = function(a) {
   reset_stream(stream, pos = 1001)
@@ -632,14 +640,14 @@ sapply(algorithms, FUN = function(a) {
 
 
 ###################################################
-### code chunk number 77: stream.Rnw:2930-2932
+### code chunk number 78: stream.Rnw:2940-2942
 ###################################################
 set.seed(0)
 stream <- DSD_Memory(DSD_Benchmark(1), n = 5000)
 
 
 ###################################################
-### code chunk number 78: stream.Rnw:2942-2950
+### code chunk number 79: stream.Rnw:2952-2960
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100, biased = TRUE),
@@ -652,7 +660,7 @@ algorithms <- list(
 
 
 ###################################################
-### code chunk number 79: stream.Rnw:2961-2966
+### code chunk number 80: stream.Rnw:2971-2976
 ###################################################
 evaluation <- lapply(algorithms, FUN = function(a) {
   reset_stream(stream)
@@ -662,7 +670,7 @@ evaluation <- lapply(algorithms, FUN = function(a) {
 
 
 ###################################################
-### code chunk number 80: stream.Rnw:2982-2985
+### code chunk number 81: stream.Rnw:2992-2995
 ###################################################
 Position <- evaluation[[1]][ , "points"]
 cRand <- sapply(evaluation, FUN = function(x) x[ , "cRand"])
@@ -670,7 +678,7 @@ head(cRand)
 
 
 ###################################################
-### code chunk number 81: dynamic
+### code chunk number 82: dynamic
 ###################################################
 matplot(Position, cRand, type = "l", lwd = 2)
 legend("bottomleft", legend = names(evaluation),
@@ -678,13 +686,13 @@ legend("bottomleft", legend = names(evaluation),
 
 
 ###################################################
-### code chunk number 82: dynamic_box
+### code chunk number 83: dynamic_box
 ###################################################
 boxplot(cRand, las = 2, cex.axis = .8)
 
 
 ###################################################
-### code chunk number 83: stream.Rnw:3043-3051 (eval = FALSE)
+### code chunk number 84: stream.Rnw:3053-3061 (eval = FALSE)
 ###################################################
 ## library("stream")
 ## con <- gzcon(
@@ -697,7 +705,7 @@ boxplot(cRand, las = 2, cex.axis = .8)
 
 
 ###################################################
-### code chunk number 84: stream.Rnw:3057-3059 (eval = FALSE)
+### code chunk number 85: stream.Rnw:3067-3069 (eval = FALSE)
 ###################################################
 ## dstream <- DSC_DStream(gridsize = .5, gaptime = 10000L, lambda = .01)
 ## update(dstream, stream2, n = 4000000, verbose = TRUE)
